      Globals [
            vault patch-ren-max-mem return-food
            inherited-wants inherited-money genetic-marker-search genetic-marker-offspring inheritance-done living-children            ; inheritance variables
            pop-increase1                                                                                                              ; allows the user to increase the population of 'dead' populations
            employment-benefits
            Agent-seediness patch-seediness gi

            ;;;;;;;;;;;;;;Bank;;;;;;;;;;;;;;;

            Money-vault                            ; This tracks the overall amount of money created in the system. It is also used as a check that there are no leaks in the programmes money system.


            ;;;;;;;;;;; GLOBAL CHARTING VARIABLES ;;;;;;;;

            starvation             ; tracks death by starvation
            child-starve           ; tracks child starvation
            charting-interval      ; sets the time between each mark on the charts
            interval-count         ; used to track the charting-interval
            pop-chart              ; used to aggregate population figures between charting intervals. The average between the intervals is calculated and charted.
            totalpop               ; population during a given iteration
            totalpop-adult         ; tracks population of adults
            death-age              ; tracks death by old age
            number-dead            ; denominator to figure out average age at death
            death-rate             ; tracks all deaths
            birth-rate             ; tracks the rate of birth.
            ave-death-age          ; tracks the age at death
            gini-base-line         ; creates a reference line on the Gini graph
            needs-ave-pricing      ; calculates the average pricing over the entire system.
            total-trade-needs      ; tracks the total number of trades down. This is used as the denominator in the calculation of average needs pricing.
            needs-ave-wage         ; used to aggregate wage figures. The average between the intervals is calculated and charted.
            number-pay-packets     ; adds up all the pay packets. Used as denominator in the average wage.
            needs-in-stock         ; tracks needs held by agents
            GDP                    ; This is aggregate physical production
            charting-pop           ; used to create per capita graphs
            GDP-money              ; GDP calculated using money
            GDP-m-growth           ; used to calculated long-term GDP growth.
            vault-last             ; remembers last the vault value from the last iteration
            money-supply-increase  ; used to calculate long-term money supply increase.
            growth-last gdp-overall-growth overall-m-growth overall-money-supply-increase
            year-tracker
            unemployment
            ave-profit
            gross-profits
            system-price-average
            wander-death  ; tracks deaeths by exploration


           ex-prod ex-wp p-r ui gdp-plot



]

Breed [ adult adults ]
breed [ child childs ]

patches-own
[ patch-id
  renewables-here       ; amount of renewables available on this patch
  harvest-cost          ; how much resistance covers the harvesting of renewables
  harvest               ;

  fixed-here            ; amount of 'wants' available on this patch
  extraction-cost       ; how much resistance covering the harvest of this fixed resource
  extraction

;  carrying-cap          ; maximum number patch can support without technology


  max-employ-needs      ; number required to harvest
  min-employ-needs
  efficient-workforce
  patch-worth-needs
  employment-wants      ; number required to extract

  store-needs
  store-wants


  needs-pricing-up
  needs-pricing-down
  needs-wages-up
  needs-wages-down

  price-needs
  price-wants

  wage-needs
  wage-wants

  hiring                ; whether employment is required

  wage                  ; wage per agent
  wage-bill             ; total wage bill for that iteration
  wage-price-needs      ; wage paid to workers for productivity of needs
  wage-price-wants      ; wage paid to workers for productivity of wants

  todays-wage-needs     ; wage bill of needs
  borrow-needs

  till-needs              ; revenue from needs sales
  business-license-needs  ; stores the 'who' of the owner
  workforce-n-people      ; agent-set of need workforce
  workforce-n-number      ; number of need workforce
  profit-needs            ; tracks whether the business is in profit-needs or not
  till-last               ; what the till was last iteration
  trade-needs             ; was there any trading done last iteration?
  trade-n-last            ; memory of trade-needs
  business-close
  my-bank-needs           ; bank account of need business


  ; bank business variables
  Bank-id
  loans
  equity

  all-food



]


turtles-own
[ age              ; roughly analogous to years
  children         ; how many children
  needs            ; store of needs
  wants            ; store of wants
  money
  income           ; income this iteration

  labour
  labour-needs     ; labour dedicated to harvesting
  labour-wants     ; labour dedicated to extracting
  labour-stuff

  employed
  employed-needs   ; is the agent employed on this patch
  market-range     ; range of market awareness
  job-range        ; how far an agent can see jobs

  raising-children           ; money needed to raise children
  child-caring               ; the extent to which the parent tends to children
  child-feeding-anticipation ; anticipated need to feed children
  iteration-needs            ; sum of 'needs' required during an iteration

  genetic-id
  parent-dna
  time-track              ; adjusts birth cycle if year is divided


  wander             ; variable used to control movement
  total-wealth       ; tracks an agent's wealth
  class-ranking      ; wealth ranking
  wander-food        ; tracks whether death is a result of exploration or not



  ;;;;;;;;; EVOLUTIONARY VARIABLES ;;;;;;;;;;;

  mutation           ; mutation variable
  movement           ; likelihood of moving
  fertile            ; the likelihood reproduction
  income-hunting     ; propensity to go exploring
  nurture-needs
  nurture-money      ; how much money is set aside for the child at birth
  child-need-buffer  ; variable associated with need-birth-buffer

; Consumer

  saving-needs       ; the stock of food the agent tries to maintain.

  satiation-needs    ; agent satiation of food once children and savings are taken into account. Creates limited demand

  saving-rate-money  ; the rate at which agent stops discretionary spending
  saving-of-money    ; actual amount of 'savings account'

; Business

  wages-up
  wages-down
  prices-up
  prices-down


  business-inheritance ; variable facilitating business transferral
  entrepreneurial      ; how likely an agent is to try to set up a new business


  ;;;;;;;;; BUSINESS VARIABLES ;;;;;;;;;;;

  business-ownership
  bank-ownership


;;;;;;;;;;; HUNTER/GATHERER VARIABLES ;;;;;;;;;;;;;;;;
  last-income-needs  ; hunter/gatherer variable
  exploring
  vision
  movement1          ; likelihood of exploring

  ]




to setup

  clear-all
  setup-patches
  set pop-increase1 0
  setup-people
  set charting-interval chart-interval
  set totalpop population
  set vault-last 1

  reset-ticks

end


to setup-people
  ifelse input-seeds = false [ set agent-seediness new-seed
                               set agent_seed agent-seediness ]
                             [ set agent-seediness agent_seed ]
  random-seed agent-seediness

  if pop-increase1 = 0 or mortality = true [ set pop-increase1 population + 1 ]
  set-default-shape turtles "person"
  create-turtles pop-increase1
    [                               ; creates and randomly places the turtles
    move-to one-of patches
    set size .7
    set age child-dependency + random ( Old-Age - child-dependency )                    ; sets random age
    set breed adult
    set labour starting-labour                              ; inputs from slider
    set labour-needs labour                                 ; this anticipates different labour in later version
    set market-range market-sight
    set job-range job-sight
    set child-caring random-float .5
    set entrepreneurial 1000
    set mutation random 200
    set movement random 200
    set child-need-buffer random-float need-birth-buffer
    if NBB_Evolve = false [ set child-need-buffer need-birth-buffer ]
    set fertile 1 + random fertility
    set income-hunting random 200
    set nurture-needs random-float 1
    set nurture-money random-float 1
    set needs min-food * ( 10 + random 4 )
    set genetic-id who
    set saving-needs random-float 5
    set saving-rate-money random-float .8
    set child-feeding-anticipation random-float 3

    set prices-up ( random-float .5 ) / 100
    set prices-down ( random-float .5 ) / 100
    set business-ownership 0
    set pop-increase1 0
    ]
  if turtle 0 != nobody [ ask turtle 0 [ die ]]
end


  to setup-patches

  ifelse input-seeds = false [ set patch-seediness new-seed
                               set patch_seed patch-seediness ]
                             [ set patch-seediness patch_seed ]

  random-seed patch-seediness

  let patch-id-increment 10000
  ask patches
    [ set patch-id patch-id-increment                                 ; creates unique patch ID for store purposes.
      set patch-id-increment patch-id-increment + 1
      set patch-ren-max-mem max-renewable-resources
      set renewables-here random max-renewable-resources              ; renewables-here is a user adjustable slider
      set harvest-cost 1 + random-float renewable-harshness           ; Renewable-Harshness is a user adjustable slider.


      set max-employ-needs floor ( renewables-here / min-food )       ; figures out maximum number of agents supported by the food on this patch
      if (( max-employ-needs * starting-labour ) - harvest-cost ) / min-food < max-employ-needs [ set max-employ-needs 0 ]     ; if resistance is too high, it is not viable without technology
      if max-employ-needs > 0 [ set efficient-workforce floor (( renewables-here + harvest-cost ) / starting-labour )          ; figures out most efficient workforce
                                set patch-worth-needs renewables-here / harvest-cost / min-food
                                set min-employ-needs ceiling ( harvest-cost / starting-labour ) ]


      set wage-price-needs min-food / starting-labour
      set price-needs 1

      set business-license-needs 0

      colour-patch ]

    ; ask patches [set harvest-cost (sum [ harvest-cost ] of patches in-radius 1) / 9]   ; smooths out the resistance to harvesting
    repeat renewable-soft-patch
         [ ask one-of patches [ set harvest-cost 1 ]]
end



to colour-patch
  set pcolor scale-color lime (renewables-here / harvest-cost / 3.5 )  ( patch-ren-max-mem * 3 )  (-(patch-ren-max-mem) * .8 )
;  if harvest-cost > 1.5 * harshness-memory [ set pcolor scale-color sky (renewable-resource-here / harvest-cost / 4)  30  -10 ]

end



;******************************************************************************************************************************************************************
;*************************MAIN PROGRAMME***************************************************************************************************************************
;******************************************************************************************************************************************************************




to go ;Monetary     ;  This is a 'go' button.

tick

if money-vault > 8e18 [ stop ]
if count turtles < 4 [ stop ]
if pop-increase > 0 and mortality = false [ set pop-increase1 pop-increase1 + ( totalpop * ( pop-increase / 100 ))
                                       if pop-increase1 > 1 [ set pop-increase1 floor pop-increase1
                                                              setup-people ]]

ask patches [

    if till-needs > 0 [ let tax till-needs * asset-tax
                        set till-needs till-needs - tax
                        set money-vault money-vault - tax ]

    ifelse till-needs - till-last >= 0 [ set profit-needs 1 ]
                                       [ set profit-needs 0 ]

    set gross-profits gross-profits + till-needs - till-last
    set till-last till-needs

    if business-license-needs > 0 [ conduct-need-business ]

    set trade-n-last trade-needs
    set trade-needs 0 ]



ask turtles [


      if age + 1 > child-dependency [ set breed adult ]
      if money > 0 [ let tax money * property-tax
                     set money money - tax
                     set money-vault money-vault - tax ]
      set saving-of-money saving-rate-money * money


      if breed = adult [ if employed = 0 [ get-hired ]

                         if employed = 0 [ set wander 1
                                           move
                                           get-hired ]
                         if business-license-needs = 0 [ acquire-ownership-needs ]
                         if employed = 0 [ set money money + employment-benefits
                                           set money-vault money-vault + employment-benefits ]

                         set iteration-needs min-food + raising-children + ( saving-needs * min-food )
                         if needs < iteration-needs [ set satiation-needs 0 ]
                         set raising-children 0
                         if count turtles < 2 [ stop ]
                         Repeat Buy-cycles [ if satiation-needs = 0 and money > 0 [ buy-needs ]]

                         if random entrepreneurial = 0 [ setup-new-business ]
                         if employed = 0 and hiring = 0 [ set wander 1
                                                          move ]
                         if random income-hunting = 0 [ set wander 2
                                                        move ]
                         set needs needs - ( min-food / year-division )
                         if needs < 0 [ set starvation starvation + ( 1 / totalpop )
                                        brown-bread ]
                         ]


      set age age + ( 1 / year-division )
      if age > old-age and random 7 = 0 [ brown-bread ]

;*****************CHILDREN'S CODE********************************************************************************

      if age < child-dependency
                        [ let feeding-child min-food / (child-dependency - age) / year-division
                          if child-care = false [ set feeding-child 0 ]
                          set needs needs - feeding-child
                          let parental-care parent-dna
                          if any? turtles with [ genetic-id = parental-care ]
                                   [ ask one-of turtles with [ genetic-id = parental-care ]
                                        [ ifelse needs > feeding-child
                                              [ set needs needs - feeding-child
                                                ifelse child-budget = true [ set raising-children raising-children + ( feeding-child * child-caring ) ]
                                                                         [ set raising-children 0 ]]
                                              [ set feeding-child needs
                                                set needs 0
                                                ifelse child-budget = true [ set raising-children raising-children + ( feeding-child * child-caring ) ]
                                                                         [ set raising-children 0 ]]]
                                        ]
                          set needs needs + feeding-child
                          if needs < 0 [ set iteration-needs 0 - needs
                                         set satiation-needs 0
                                         Repeat Buy-cycles [ if satiation-needs = 0 and money > 0 [ buy-needs ]]
                                         if needs < 0 [ set child-starve child-starve + ( 1 / totalpop )
                                                        brown-bread ]]
                          if age + ( 1 / year-division ) >= child-dependency [ set breed adult ]]

;*****************REPRODUCTION************************************************************************************

      if age > child-bearing-age and time-track >= year-division [ if random (age + children ^ 2) < fertile and needs > (  child-need-buffer * min-food ) [ birth ]
                                                                   set time-track 0 ]
      set time-track time-track + 1

;*********Turtle Graph and Gini Variable*********************

if wealth-defined = "Money Only" [ set total-wealth  money ]
if wealth-defined = "Assets" [ set total-wealth money + (needs * system-price-average ) ]]



;****************GRAPHING****************************************************************************************

if totalpop < 3 [ stop ]
set year-tracker year-tracker + 1
if year-tracker = year-division [
   if ticks < 100 [ set overall-money-supply-increase 0
                    set gdp-overall-growth 0 ]

   ifelse vault-last > 0 [ set money-supply-increase 100 * ( money-vault - vault-last ) / vault-last
                           set vault-last money-vault
                           set overall-money-supply-increase overall-money-supply-increase + money-supply-increase ]
                         [ set money-supply-increase 0
                           set vault-last money-vault ]

   ifelse growth-last > 0 [ set overall-m-growth 100 * ( GDP-m-growth - growth-last ) / growth-last
                            set growth-last GDP-m-growth
                            set gdp-overall-growth gdp-overall-growth + overall-m-growth
                            set GDP-m-growth 0 ]
                          [ set gdp-overall-growth 0
                            set growth-last GDP-m-growth
                            set GDP-m-growth 0 ]



   if ticks < year-division + 100 and ticks > 99
                [ set overall-money-supply-increase overall-money-supply-increase * ticks
                  set gdp-overall-growth gdp-overall-growth * ticks ]

   set year-tracker 0 ]

chart
chart-money
if ticks >= start-charts [ if charting-interval = interval-count [ zero-chart-variables ]]
if charting-interval != chart-interval [ set charting-interval chart-interval ]
if stop-simulation * year-division = ticks [ stop ]
end

;********************* TRADING **********************************************************************************************

    to buy-needs
       let iteration-nds iteration-needs
       let cash money
       let trade-money 0
       let trade-goods 0
       if any? patches in-radius market-range with [ store-needs > 0 ] [
           ask min-one-of patches in-radius ( market-range ) with [ store-needs > 0 ] [ price-needs ]
                [ ifelse store-needs > iteration-nds [ set trade-goods iteration-nds ]
                                                     [ set trade-goods store-needs ]
                  if trade-goods < 0 [ set trade-goods 0
                                       set store-needs 0 ]
                  if price-needs < 0 [ set price-needs trade-minimum ]
                  if trade-goods > 0 [ set trade-money trade-goods * price-needs ]
                  if trade-money > cash [ set trade-money cash ]
                  set trade-goods trade-money / price-needs
                  set store-needs store-needs - trade-goods
                  set till-needs till-needs + trade-money
                  if store-needs < trade-minimum [ set store-needs 0 ]

                 ;*********** Graphing *********************

                  set GDP-money GDP-money + trade-money
                  set GDP-m-growth GDP-m-growth + trade-goods
                  set needs-ave-pricing needs-ave-pricing + price-needs
                  set total-trade-needs total-trade-needs + trade-goods
                  set trade-needs 1 ]

           set needs needs + trade-goods
           set money money - trade-money
           if money < 0 [ set money-vault money-vault + money
                          set money 0 ]
           set GDP GDP + trade-goods

           if unlimited-demand = false [ if needs > iteration-needs and saving-of-money > money [ set satiation-needs 1 ]]
           if breed = child and needs > iteration-needs [ set satiation-needs 1 ]
          ]
    end




    to buy-wants


    end

    to buy-stuff

    end




    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;Patch Subroutines;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    to conduct-need-business

          set workforce-n-people adult-here with [ employed-needs = 1 ]
          set workforce-n-number count workforce-n-people

          if store-needs = 0 and trade-n-last = 1 [ sell-price-needs-up ]

          set harvest ( workforce-n-number * starting-labour ) - harvest-cost
          if harvest < 0 [ set harvest 0 ]

          if harvest > renewables-here [ set harvest renewables-here ]

          set store-needs store-needs + ( harvest / year-division )
          set wage-bill harvest * wage-price-needs / year-division
          set needs-ave-wage needs-ave-wage + wage-bill
          set number-pay-packets number-pay-packets + workforce-n-number

          if workforce-n-number > 0 [ set todays-wage-needs wage-bill / workforce-n-number ]
          ask workforce-n-people [ if income-tax > 0 [ let tax todays-wage-needs * income-tax
                                                       set money-vault money-vault - tax
                                                       set money money - tax ]
                                   set money money + todays-wage-needs
                                   set till-needs till-needs - todays-wage-needs ]


          let hiring-efficiency max-employ-needs
          if hire-efficiency = true [ set hiring-efficiency efficient-workforce ]                 ; programming note: could set this as evolutionary
          if workforce-n-number > hiring-efficiency + 1 [ set hiring 0
                                                          fire-someone ]

          if profit-needs = 0 [ sell-price-needs-up
                                wage-price-needs-down ]

          if profit-needs = 0 and trade-n-last = 0 [ if store-needs > 0 [ sell-price-needs-down ]
                                                     wage-price-needs-down
                                                     set hiring 0
                                                     fire-someone ]


          if profit-needs = 1 and trade-n-last = 1 and store-needs > harvest [ set hiring 0
                                                                               fire-someone ]

          If workforce-n-number < min-employ-needs  [ set hiring 1
                                                      wage-price-needs-up ]  ; if price-needs / wage-price-needs > starting-labour / min-food [






  ;****************borrow money ************************************************


          if borrow-needs < 0 [ let loan-repayment borrow-needs * principle
                                let interest-payment borrow-needs * interest
                                set money-vault money-vault + loan-repayment
                                set borrow-needs borrow-needs - loan-repayment
                                set till-needs till-needs + loan-repayment + interest-payment
                                let my-bank my-bank-needs
                                ask one-of patches with [ Bank-id = my-bank ]
                                          [ set loans loans + loan-repayment
                                            set equity equity - interest-payment ]]


          if till-needs < 0
               [ ifelse money-vault < 10 ^ reserve or count turtles-here = 0
                      [ let loan-today till-needs                                                               ; if the borrow subroutine is triggered, 'till-needs' will be negative.
                        set money-vault money-vault - loan-today
                        set till-needs till-needs - loan-today
                        ;set till-last till-last - loan-today
                        ]

                      [ if sum [ Bank-id ] of patches in-radius ( market-sight * 3 ) = 0 [ create-bank ]
                        if my-bank-needs = 0 [ let acquire-bank 0
                                               ask min-one-of patches with [ Bank-id > 0 ] [ distance myself ] [ set acquire-bank Bank-id ]
                                               set my-bank-needs acquire-bank ]
                        let loan-today till-needs
                        set borrow-needs borrow-needs + loan-today
                        set money-vault money-vault - loan-today
                        set till-needs till-needs - loan-today
           ;             set till-last till-last - loan-today


                        ]]

 ;***************Profits***********************************************************


          if till-needs > 2 * wage-bill
                                  [ let dividend till-needs - wage-bill
                                    let d-tax dividend * dividend-tax
                                    set till-needs till-needs - dividend
                                    set till-last till-last - dividend
                                    set money-vault money-vault - d-tax
                                    set dividend dividend - d-tax
                                    let business-owner business-license-needs
                                    ask one-of turtles with [ who = business-owner ] [ set money money + dividend
                                                                                       if random 10 = 0 [ setup-new-business ]]]

          if equity > 0 [ let dividend equity * .99                ; this could be an evolutionary number
                          let d-tax dividend * dividend-tax
                          set equity equity - dividend
                          set money-vault money-vault - d-tax
                          set dividend dividend - d-tax
                          let banking-owner bank-id
                          ask one-of turtles with [ who = banking-owner ] [ set money money + dividend ]]





          if profit-needs = 0 and trade-n-last = 0 or workforce-n-number = 0
                                                       [ ifelse business-close > close-sensitivity
                                                                  [ let remaining-money till-needs
                                                                    let remaining-food store-needs
                                                                    let owner-number business-license-needs
                                                                    ask workforce-n-people [ set employed 0 ]
                                                                    set business-license-needs 0
                                                                    set till-needs 0
                                                                    set till-last 0
                                                                    set store-needs 0
                                                                    ask one-of turtles with [ who = owner-number ] [ set money money + remaining-money ]
                                                                    set business-close 0 ]
                                                                  [ set business-close business-close + 1 ]]

          if workforce-n-number > 0 [ set business-close 0 ]


    end




;*****************************************************************************************************************************
;;;;;;;;;;;;;;;;;;;;;;;;;; End Patch Subroutines ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;*****************************************************************************************************************************





;******************HIRING**************************************************************************************************

to get-hired

  if [ hiring ] of patch-here = 1 [ set employed 1
                                    set employed-needs 1 ]

end

to fire-someone


  ifelse workforce-n-number > min-employ-needs [ ask one-of workforce-n-people [ set employed-needs 0
                                                                                 set employed 0
                                                                                 set workforce-n-number workforce-n-number - 1 ]]
                                               [ set business-close business-close + 1 ]
  ; set workforce-n-people adult-here with [ employed-needs = 1 ]

end

;****************BUSINESS OWNERSHIP*****************************************************************************************


to setup-new-business

  let opportunity patches in-radius market-range with [ business-license-needs = 0 and patch-worth-needs > 0 ]
  if count opportunity > 0
    [ set employed 0
      move-to max-one-of opportunity [ patch-worth-needs ]
      acquire-ownership-needs
      get-hired ]

end


to acquire-ownership-needs

  let who-number who
  set needs-pricing-up prices-up
  set needs-pricing-down prices-down
  set business-ownership 1
  set business-license-needs who
  get-hired

end

;****************CREATE BANK***********************************************************************************************


to create-bank

    let bank-license 0
    let new-banker 0
    ask max-one-of turtles in-radius ( market-sight * 2 ) [ money ] [ set bank-id who ]

end

;******************PRICE CHANGES*******************************************************************************************


to sell-price-needs-up
    if price-needs > max [ price-needs ] of other patches [ stop ]
    set price-needs price-needs + ( price-needs * needs-pricing-up )
end

to sell-price-needs-down
    if price-needs < min [ price-needs ] of other patches [ stop ]
    set price-needs price-needs - (price-needs * needs-pricing-down)
    if price-needs < trade-minimum [ set price-needs trade-minimum ]
end

to wage-price-needs-up
    if wage-price-needs > max [ wage-price-needs ] of other patches [ stop ]
    set wage-price-needs wage-price-needs + ( wage-price-needs * needs-pricing-up )
end

to wage-price-needs-down
    if wage-price-needs < min [ wage-price-needs ] of other patches [ stop ]
    set wage-price-needs wage-price-needs - (wage-price-needs * needs-pricing-down)
    if wage-price-needs < trade-minimum [ set wage-price-needs trade-minimum ]
end





;****************** MOVEMENT **********************************************************************************************


    to move

     if wander = 1                                                                      ; 'wander' is set to 1 when an agent isn't finding the 'needs' it is seeking.
      [ move-to max-one-of patches in-radius job-range [ todays-wage-needs * hiring ]      ; 'resource-value' is a patch calculated variable to vaguely indicate better prospect
        set employed 0
        set employed-needs 0
        fd random-float .4
        set wander 0 ]

     if wander = 2                                                       ; 'wander' is set to 2 when and agent chooses to explore.
      [ set heading random 360
        set employed 0
        set employed-needs 0
        fd job-range + random ( job-range * 3 )
        set wander 1
        move ]

    end


 ;***************** REPRODUCTION **********************************************************************************************



    to birth
      if mortality = false [ stop ]
      if count turtles < 2 [ stop ]
      let temp-mutation 0
      let temp-vision 0
      let temp-income-hunting 0
      let temp-travel-distance 0
      let temp-fertile 0
      let temp-movement 0
      let temp-movement1 0
      let temp-nurture-needs 0
      let temp-child-need-buffer 0
      let temp-saving-needs 0
      let temp-entrepreneurial 0
      let temp-child-caring 0


     if count adult > 2 [ Ask min-one-of other adult [distance myself]
            [ set temp-mutation mutation
              set temp-fertile fertile
              set temp-movement movement
              set temp-movement1 movement1
              set temp-fertile fertile
              set temp-nurture-needs nurture-needs
              set temp-income-hunting income-hunting
              set temp-child-need-buffer child-need-buffer
              set temp-saving-needs saving-needs
              set temp-entrepreneurial entrepreneurial
              set temp-child-caring child-caring
            ]]

     hatch 1 [

       set birth-rate birth-rate + ( 1 / totalpop )
       set parent-dna genetic-id
       set genetic-id who
       set age 0
       set needs needs * nurture-needs
       set money money * nurture-money
       set employed 0
       set employed-needs 0
       set breed child
       set raising-children 0
       set children 0
       set business-ownership 0
       set needs 0
       set wander-food 0
       if sexual-rep = true [ if random 2 = 0 [ set mutation temp-mutation ]
                              if random 2 = 0 [ set fertile temp-fertile ]
                              if random 2 = 0 [ set movement temp-movement ]
                              if random 2 = 0 [ set movement1 temp-movement1 ]
                              if random 2 = 0 [ set fertile temp-fertile ]
                              if random 2 = 0 [ set income-hunting temp-income-hunting ]
                              if random 2 = 0 [ set child-need-buffer temp-child-need-buffer ]
                              if random 2 = 0 [ set saving-needs temp-saving-needs ]
                              if random 2 = 0 [ set entrepreneurial temp-entrepreneurial ]
                              if random 2 = 0 [ set child-caring temp-child-caring ]
                              ]
      dead-birth


      ]

          set needs needs - ( needs * nurture-needs )
          set money money - (money * nurture-money)
          set children children + 1

    end

    to dead-birth

         if mortality = false [ set age 0
                           set employed 0
                           set needs needs * %-Food-Inherit
                           if eternal-children = true [ set breed child ]]
         if random 10000 < mutation [
               set mutation mutation + random 10 - random 10
                if mutation < 1 [ set mutation 1 ]]
         if random 10000 < mutation [
               set entrepreneurial entrepreneurial + random 10 - random 10
                if entrepreneurial < 0 [ set entrepreneurial 0 ]]
         if random 10000 < mutation [
               set nurture-needs nurture-needs + (random-float 1 / 10) - (random-float 1 / 10)
                if nurture-needs < 0 [set nurture-needs 0]
                if nurture-needs > 1 [set nurture-needs 1]]
         if random 10000 < mutation [
               set child-caring child-caring + (random-float 1 / 10) - (random-float 1 / 10)
                if child-caring < 0 [set child-caring 0]]
         if random 10000 < mutation [
               set nurture-money nurture-money + (random-float 1 / 10) - (random-float 1 / 10)
                if nurture-money < 0 [set nurture-money 0]
                if nurture-money > 1 [set nurture-money 1]]
         if random 10000 < mutation [
               set fertile fertile + random-float 2 - random-float 2
                if fertile < 0 [set fertile 0]]
         if random 10000 < mutation [
               set movement movement - random 2 + random 2]
               if movement < 0 [ set movement 0 ]
         if random 10000 < mutation [
               set income-hunting income-hunting - random 10 + random 10 ]
               if income-hunting < 0 [ set income-hunting 0 ]
         if random 10000 < mutation and NBB_Evolve = true [
               set child-need-buffer child-need-buffer + random-float 1 - random-float 1
               if child-need-buffer < 0 [ set child-need-buffer 0 ]]
         if random 10000 < mutation [
               set saving-needs saving-needs + random-float .5 - random-float .5
               if saving-needs < 0 [ set saving-needs 0 ]]
         if random 10000 < mutation [
               set saving-rate-money saving-rate-money + random-float .2 - random-float .2
               if saving-rate-money < 0 [ set saving-rate-money 0 ]
               if saving-rate-money > 1 [ set saving-rate-money 1 ]]
         if random 10000 < mutation [
               set child-feeding-anticipation child-feeding-anticipation + random-float .3 - random-float .3
               if child-feeding-anticipation < 0 [ set child-feeding-anticipation 0 ]]

;****************HUNTER/GATHERER****************************************************

         if random 10000 < mutation [
               set movement1 movement1 - random 2 + random 2]
               if movement1 < 0 [ set movement1 0 ]
         if random 10000 < mutation [
               set vision vision + random-float 1 - random-float 1
                if vision < 0 [ set vision 0 ]]

      end



  ;************** DYING AND INHERITANCE **********************************************************************************************

 to brown-bread


  if needs < 0 [ set needs 0 ]
  if age >= old-age [ set death-age death-age + ( 1 / totalpop ) ]


  if mortality = false [ set number-dead number-dead + 1
                    set ave-death-age ave-death-age + age
                    set death-rate death-rate - ( 1 / totalpop )                                    ; This is for graphing purposes.
                    set birth-rate birth-rate + ( 1 / totalpop )
                    set number-dead number-dead + 1
                    set ave-death-age ave-death-age + age
                    dead-birth
                    stop ]


  if count turtles > 1 [

  set return-food needs * %-Food-Inherit
  set inherited-wants wants * ( .85 + random-float .15 )                            ; This simulates people throwing away old stuff.
  set inherited-money money

  set genetic-marker-search genetic-id
  set genetic-marker-offspring parent-dna
  set inheritance-done 0
  let business-id who
  let inheritance-ownership patches with [ business-license-needs = business-id ]
  let transfer-bank patches with [ bank-id = business-id ]
  let bank-account-transfer patches with [ my-bank-needs = business-id ]

  if inheritance > 0 and age < child-dependency [
    if any? other turtles with [ genetic-id = genetic-marker-offspring ]             ; Is the parent living?
      [ ask one-of turtles with [ genetic-id = genetic-marker-offspring ]
        [ let my-id who
          set wants wants + inherited-wants
          set money money + inherited-money
          set needs needs + return-food
          if inheritance-ownership != nobody [ ask inheritance-ownership [ set business-license-needs my-id ]]
          if transfer-bank != nobody [ ask transfer-bank [ set bank-id my-id ]]
          if bank-account-transfer != nobody [ ask bank-account-transfer [ set my-bank-needs my-id ]]
          set inheritance-done 1 ]]]


 if inheritance > 1 and inheritance-done = 0 [
    if any? other turtles with [ parent-dna = genetic-marker-search ]                ; If no children, is the parent living?
      [ ask one-of other turtles with [ parent-dna = genetic-marker-search ]         ; looking for surviving children
        [ let my-id who
          set wants wants + inherited-wants
          set money money + inherited-money
          set needs needs + return-food
          if inheritance-ownership != nobody [ ask inheritance-ownership [ set business-license-needs my-id ]]
          if transfer-bank != nobody [ ask transfer-bank [ set bank-id my-id ]]
          if bank-account-transfer != nobody [ ask bank-account-transfer [ set my-bank-needs my-id ]]
          set inheritance-done 1
          ]]]

   if inheritance > 2 and inheritance-done = 0 [
    if any? other turtles with [genetic-id = genetic-marker-offspring]                ; If no children, is the parent living?
      [ ask one-of other turtles with [ genetic-id = genetic-marker-offspring ] ;
        [ let my-id who
          set wants wants + inherited-wants
          set money money + inherited-money
          set needs needs + return-food
          if inheritance-ownership != nobody [ ask inheritance-ownership [ set business-license-needs my-id ]]
          if transfer-bank != nobody [ ask transfer-bank [ set bank-id my-id ]]
          if bank-account-transfer != nobody [ ask bank-account-transfer [ set my-bank-needs my-id ]]
          set inheritance-done 1
          ]]]

   if inheritance > 3 and inheritance-done = 0 [
    if any? other turtles with [parent-dna = genetic-marker-offspring]               ; No parents or children, how about siblings? If yes, then here is the Will ...
      [ ask one-of other turtles with [ parent-dna = genetic-marker-offspring ]
        [ let my-id who
          set wants wants + inherited-wants
          set money money + inherited-money
          set needs needs + return-food
          if inheritance-ownership != nobody [ ask inheritance-ownership [ set business-license-needs my-id ]]
          if transfer-bank != nobody [ ask transfer-bank [ set bank-id my-id ]]
          if bank-account-transfer != nobody [ ask bank-account-transfer [ set my-bank-needs my-id ]]
          set inheritance-done 1
          ]]]

   if inheritance-done = 0 [
    Ask min-one-of other turtles [ distance myself ]
        [ let my-id who
          set wants wants + inherited-wants
          set money money + inherited-money
          set needs needs + return-food
          if inheritance-ownership != nobody [ ask inheritance-ownership [ set business-license-needs my-id ]]
          if transfer-bank != nobody [ ask transfer-bank [ set bank-id my-id ]]
          if bank-account-transfer != nobody [ ask bank-account-transfer [ set my-bank-needs my-id ]]
          ]]]


    set death-rate death-rate - ( 1 / totalpop )                                    ; This is for graphing purposes.
    set number-dead number-dead + 1
    set ave-death-age ave-death-age + age
    die                                                                            ; finally, the last breath is drawn.

end





    ; ****************** CHARTING ***************************************************************************************

  to chart

      set totalpop count turtles
      if count adult = 0 [ stop ]
      set unemployment unemployment + (( count adult - sum [ employed-needs ] of adult ) / count adult ) * 100
      set charting-pop charting-pop + totalpop
      set interval-count interval-count + 1
      set pop-chart pop-chart + totalpop
      let count-businesses-in-profit count patches with [ trade-needs > 0 ]
      if count-businesses-in-profit > 0 [ set ave-profit ave-profit + count patches with [ profit-needs = 1 and trade-needs > 0 ] / count-businesses-in-profit ]
      set needs-in-stock needs-in-stock + ( sum [ needs ] of turtles / totalpop )
      if totalpop < 2 [ stop ]
      if ticks = start-charts - charting-interval [ zero-chart-variables ]
      if ticks >= start-charts [ if charting-interval = interval-count
       [

         set-current-plot "Population"
         Set-current-plot-pen "default"
         plot pop-chart / charting-interval

         set-current-plot "Per Capita Productivity"
         Set-current-plot-pen "default"
         set ex-prod GDP / charting-pop
         plot GDP / charting-pop
         Set-current-plot-pen "reference"
         plot .6

         set-current-plot "Real Production"
         Set-current-plot-pen "default"
         plot GDP / charting-interval

         set-current-plot "Food per Capita"
         Set-current-plot-pen "default"
         plot needs-in-stock / charting-interval

         set-current-plot "Longevity"
         Set-current-plot-pen "Age"
         ifelse number-dead > 0 [ plot ave-death-age / number-dead ]
                                [ plot 0 ]
         Set-current-plot-pen "45"
         plot 45

         set-current-plot "Cause of Death"
         Set-current-plot-pen "starve"
         plot starvation / charting-interval
    ;     Set-current-plot-pen "child"
    ;     plot child-starve / charting-interval
         Set-current-plot-pen "age"
         plot death-age / charting-interval

         set-current-plot "Child Caring"
         Set-current-plot-pen "Max"
         plot max [child-caring] of turtles
         Set-current-plot-pen "Ave"
         plot sum [child-caring] of turtles / totalpop
         Set-current-plot-pen "Min"
         plot min [child-caring] of turtles

         set-current-plot "Need Birth Buffer"
         Set-current-plot-pen "Max"
         plot max [Child-Need-Buffer] of turtles
         Set-current-plot-pen "Ave"
         plot sum [Child-Need-Buffer] of turtles / totalpop
         Set-current-plot-pen "Min"
         plot min [Child-Need-Buffer] of turtles

         set-current-plot "Birth and Death"
         Set-current-plot-pen "Birth"
         plot year-division * birth-rate / charting-interval
         Set-current-plot-pen "death"
         plot year-division * death-rate / charting-interval
         Set-current-plot-pen "0"
         plot 0
         Set-current-plot-pen "+5"
         plot .05
         Set-current-plot-pen "-5"
         plot -.05



       ;**************GINI*****************

        set totalpop-adult count turtles with [ breed = adult ]
        let sorted-wealths sort [ total-wealth ] of turtles with [ breed = adult ]
        let sum-wealth sum sorted-wealths
        let wealth-sum-so-far 0
        let index 0
        let gini-index-reserve 0
        repeat totalpop-adult [
          set wealth-sum-so-far (wealth-sum-so-far + item index sorted-wealths)
          set index (index + 1)
          set gini-index-reserve gini-index-reserve + ( index / totalpop-adult ) - ( wealth-sum-so-far / sum-wealth )
          ]

        ;if gini-base-line = 0 [ set gini-base-line (gini-index-reserve / totalpop) / 0.5 ]

        set-current-plot "Gini Coefficient"
        Set-current-plot-pen "gini"
        set GI (gini-index-reserve / totalpop) / 0.5
        plot GI
        Set-current-plot-pen "base"
        plot .5 ;gini-base-line

       ;***********END GINI****************


        ]
       ]

  end

  to chart-money

   if ticks >= start-charts [ if charting-interval = interval-count
    [
      set-current-plot "$ Per Capita Productivity"
      Set-current-plot-pen "default"
      plot GDP-money / charting-pop

      set-current-plot "Needs Price"
      Set-current-plot-pen "default"

      ifelse total-trade-needs > 0 [ set system-price-average needs-ave-pricing / total-trade-needs / charting-interval
                                     plot system-price-average ]
                                   [ plot 0 ]
      set employment-benefits system-price-average * jobless-benefits

      set-current-plot "Needs Wage"
      Set-current-plot-pen "default"
      ifelse number-pay-packets > 0 [ plot needs-ave-wage / number-pay-packets / charting-interval ]
                                    [ plot 0 ]
      set-current-plot "Wage/Price"
      Set-current-plot-pen "default"
      ifelse number-pay-packets > 0 and total-trade-needs > 0
                                    [ set ex-wp ( needs-ave-wage / number-pay-packets ) / ( needs-ave-pricing / total-trade-needs )
                                      plot ex-wp  ]
                                    [ set ex-wp 0
                                      plot 0 ]

      set-current-plot "% Businesses in Profit"
      Set-current-plot-pen "default"
      plot ave-profit / charting-interval

      set-current-plot "Profit Rate"
      Set-current-plot-pen "default"
      ifelse gdp-money > 0 [ set p-r gross-profits / gdp-money
                             plot p-r ]
                           [ set p-r 0
                             plot 0 ]

      set-current-plot "unemployment"
      Set-current-plot-pen "default"
      set ui unemployment / charting-interval
      plot ui ;unemployment / charting-interval

      set-current-plot "Money Supply"
      Set-current-plot-pen "default"
      plot money-vault

      set-current-plot "GDP"
      Set-current-plot-pen "default"
      set gdp-plot GDP-money / charting-interval
      plot GDP-money / charting-interval ]]


end

    to zero-chart-variables

      set interval-count 0
      set pop-chart 0
      set starvation 0
      set child-starve 0
      set death-rate 0
      set birth-rate 0
      set death-age 0
      set ave-death-age 0
      set number-dead 0
      set total-trade-needs 0
      set needs-ave-pricing 0
      set number-pay-packets 0
      set needs-ave-wage 0
      set needs-in-stock 0
      set GDP 0
      set GDP-money 0
      set charting-pop 0
      set unemployment 0
      set ave-profit 0
      set gross-profits 0


    end

 to deflate-money  ; resets the prices so simulator can keep running

   let deflation money-deflation
   Ask turtles [ set money money / deflation ]
   ask patches [ set till-needs till-needs / deflation
                 set wage-price-needs wage-price-needs / deflation
                 set price-needs price-needs / deflation ]
   set money-vault money-vault / deflation

 end

;*********************************************************************************************************************************************
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;*********************************************************************************************************************************************
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;*********************************************************************************************************************************************
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
;*********************************************************************************************************************************************
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;*********************************************************************************************************************************************
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;*********************************************************************************************************************************************
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;; HUNTER GATHERER CODE ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to Set-H/G

  setup
  ask turtles [ set movement1 random 2000
                set vision random-float 3
                set needs min-food * ( 4 + random 4 )
                set child-caring 2 + random-float 13 ]


end

to hunter/gatherer
  tick
  ask patches [ set patch-worth-needs (renewables-here / harvest-cost - (min-food * (count turtles-here with [ breed = adult ] + 1))) ; * ((sum [labour ] of turtles-here with [ breed = adult ] + 1) / harvest-cost)
  ]; if share-stores = true [ set all-food all-food * .9 ]]

  set total-trade-needs 1
  ask turtles [ if breed = adult
                 [ find-food
                   explore
                   set needs needs - ( min-food / year-division ) ]
                if breed = child [ seek-parenting ]
                set age age + ( 1 / year-division )
                birth-age-die
                set total-wealth needs ]
  if totalpop < 4 [ stop ]
  chart
  if ticks >= start-charts [ if charting-interval = interval-count [ zero-chart-variables ]]
  if charting-interval != chart-interval [ set charting-interval chart-interval ]
  if stop-simulation * year-division = ticks [ stop ]

end


to find-food


  let everyones-labour sum [ labour-needs ] of adult-here
  if Share-Stores = true [ set all-food all-food + needs
                           set needs 0 ]

  ifelse everyones-labour - harvest-cost < 0       ; if everyone's labour can't overcome the resistance, then there is no harvest
    [ set income 0
      if last-income-needs < min-food / year-division                  ; if this income and the last income was 0, it is time to consider another patch.
      [ if random movement = 0 or exploring = 1 [ set wander 1      ; 'movement' is an evolutionary variable. 'wander' is used to determine which kind of movement occurs in the 'move' subroutine
                                 set exploring 1
                                 set wander-food 1
                                 travel ]]]
    [ ifelse everyones-labour > renewables-here + harvest-cost
        [ set income renewables-here * (labour-needs / everyones-labour) ]         ; this set an agent's income in proportion to their labour in relation to all the labour present.
        [ set income labour-needs - (harvest-cost * (labour-needs / everyones-labour))]
      ifelse income > min-food / year-division [ set exploring 0 ]
                                               [ set wander-food 0 ]]
  set income income / year-division + ( all-food * labour-needs / everyones-labour)
  set all-food all-food - ( all-food * labour-needs / everyones-labour)
  set needs needs + income
  set gdp gdp + income
  set last-income-needs income                                                       ; this remembers harvesting income

end

to seek-parenting

  let feeding-child (min-food * (age / child-dependency)) / year-division
  if child-care = false [ set feeding-child 0 ]
  set needs needs - feeding-child
  if needs < feeding-child + child-caring
        [  let parental-care parent-dna
           if any? turtles with [ genetic-id = parental-care ]
                 [ ask one-of turtles with [ genetic-id = parental-care ]
                     [ ifelse needs - ( min-food / year-division ) > feeding-child + child-caring
                           [ set feeding-child feeding-child + child-caring ]
                           [ ifelse needs - ( min-food / year-division ) > 0 [ set feeding-child needs - ( min-food / year-division ) ]
                                                                             [ set feeding-child 0 ]]
                       set needs needs - feeding-child ]]
           set needs needs + feeding-child ]
   if age + ( 1 / year-division ) >= child-dependency [ set breed adult ]
end


to explore
     if random movement1 = 0 [ set wander 2
                               travel ]
end

to travel

  if wander = 1 [ repeat 3
                  [ ifelse vision < 1
                    [ set heading random 360 ]
                    [ face max-one-of patches in-radius vision [ patch-worth-needs ] ]     ; 'resource-value' is a patch calculated variable to vaguely indicate better prospects
                      fd .334 ]]

  if wander = 2 [ set heading random 360
                  repeat random-float 3 [ fd .9
                                          set heading heading + random 30 - random 30 ]
                  set wander 1
                  travel ]
  set wander 0
end


to birth-age-die

      if age > child-bearing-age and time-track >= year-division and random (age + children ^ 2) < fertile and needs > ( child-need-buffer * min-food )
                   [ birth
                     set time-track 0 ]
      if age > old-age and random ( 7 * year-division ) = 0 [ brown-bread ]
                     if needs < 0 [ ifelse wander = 0 [ set starvation starvation + ( 1 / totalpop ) ]
                                                      [ set wander-death wander-death + 1 ]
                     if breed = child [ set child-starve child-starve + ( 1 / totalpop ) ]
                     brown-bread ]
      set time-track time-track + 1
      set total-wealth needs

end
@#$#@#$#@
GRAPHICS-WINDOW
266
56
682
473
-1
-1
8.0
1
10
1
1
1
0
1
1
1
-25
25
-25
25
1
1
1
Iterations
30.0

SLIDER
239
10
407
43
max-renewable-resources
max-renewable-resources
10
100
52.0
1
1
NIL
HORIZONTAL

SLIDER
10
88
128
121
Population
Population
0
2000
1000.0
10
1
NIL
HORIZONTAL

SLIDER
10
204
129
237
old-age
old-age
0
100
85.0
1
1
NIL
HORIZONTAL

SLIDER
10
126
128
159
min-food
min-food
1
15
2.4
.1
1
NIL
HORIZONTAL

SLIDER
413
10
565
43
Renewable-Harshness
Renewable-Harshness
0
100
35.0
1
1
NIL
HORIZONTAL

BUTTON
8
50
116
83
NIL
Setup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
123
50
234
83
Run-Monetary
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
10
165
128
198
Starting-Labour
Starting-Labour
0
20
5.0
.1
1
NIL
HORIZONTAL

SLIDER
752
48
879
81
Buy-cycles
Buy-cycles
1
20
4.0
1
1
NIL
HORIZONTAL

SLIDER
745
86
884
119
Trade-Minimum
Trade-Minimum
.00001
.01
0.00108
.00001
1
NIL
HORIZONTAL

SLIDER
10
316
131
349
Child-Bearing-Age
Child-Bearing-Age
8
16
14.0
1
1
NIL
HORIZONTAL

MONITOR
717
148
791
193
NIL
count turtles
0
1
11

SLIDER
10
243
130
276
Fertility
Fertility
0
100
20.0
1
1
NIL
HORIZONTAL

PLOT
32
552
230
702
Population
Time
Population
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SLIDER
137
508
262
541
chart-interval
chart-interval
1
100
10.0
1
1
NIL
HORIZONTAL

SLIDER
10
280
130
313
Child-Dependency
Child-Dependency
1
20
16.0
1
1
NIL
HORIZONTAL

SLIDER
11
354
131
387
need-birth-buffer
need-birth-buffer
1
20
12.0
1
1
NIL
HORIZONTAL

MONITOR
387
500
509
545
Money
sum [ money ] of turtles + sum [ till-needs + equity ] of patches - money-vault
2
1
11

SLIDER
12
391
132
424
Inheritance
Inheritance
0
4
2.0
1
1
NIL
HORIZONTAL

SLIDER
719
195
869
228
Stop-Simulation
Stop-Simulation
0
100000 / year-division
1000.0
100
1
NIL
HORIZONTAL

PLOT
725
394
924
544
Gini Coefficient
NIL
NIL
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Gini" 1.0 0 -16777216 true "" ""
"base" 1.0 0 -955883 true "" ""

SLIDER
10
508
135
541
Start-Charts
Start-Charts
1
500
150.0
1
1
NIL
HORIZONTAL

SWITCH
136
391
246
424
Sexual-Rep
Sexual-Rep
0
1
-1000

SLIDER
1176
80
1305
113
Interest
Interest
0
.1
0.0
.001
1
NIL
HORIZONTAL

PLOT
230
552
479
702
Cause of Death
NIL
NIL
0.0
200.0
0.0
0.0
true
true
"" ""
PENS
"Starve" 1.0 0 -13840069 true "" ""
"Age" 1.0 0 -16449023 true "" ""

SLIDER
1174
193
1310
226
Market-Sight
Market-Sight
1
30
4.0
1
1
NIL
HORIZONTAL

PLOT
230
701
431
851
Birth and Death
Time
Death  I   Birth
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"Birth" 1.0 0 -16777216 true "" ""
"Death" 1.0 0 -16777216 true "" ""
"0" 1.0 0 -5298144 true "" ""
"+5" 1.0 0 -955883 true "" ""
"-5" 1.0 0 -955883 true "" ""

PLOT
32
701
230
851
Longevity
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"age" 1.0 0 -16777216 true "" ""
"45" 1.0 0 -955883 true "" ""

PLOT
1126
553
1326
703
Needs Price
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -14835848 true "" ""

PLOT
923
553
1123
703
Needs Wage
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -2674135 true "" ""

SWITCH
884
48
1018
81
Unlimited-Demand
Unlimited-Demand
1
1
-1000

SLIDER
751
11
879
44
%-Food-Inherit
%-Food-Inherit
0
1
0.0
.01
1
NIL
HORIZONTAL

PLOT
479
552
676
702
Food per Capita
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -10899396 true "" ""

MONITOR
1345
244
1420
289
Businesses
count patches with [ business-license-needs > 1 ]
0
1
11

PLOT
479
701
676
851
Real Production
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SWITCH
885
86
1019
119
Mortality
Mortality
1
1
-1000

PLOT
725
244
924
394
GDP
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -8630108 true "" ""

SLIDER
10
469
191
502
bottom-wealth-cutoff-%
bottom-wealth-cutoff-%
.01
middle-wealth-cutoff-%
0.43
.01
1
NIL
HORIZONTAL

SLIDER
10
430
192
463
middle-wealth-cutoff-%
middle-wealth-cutoff-%
bottom-wealth-cutoff-%
.99
0.95
.01
1
NIL
HORIZONTAL

SLIDER
1030
10
1167
43
Asset-Tax
Asset-Tax
0
1
0.0
.001
1
%
HORIZONTAL

SLIDER
1031
50
1168
83
Property-Tax
Property-Tax
0
1
0.0
.001
1
%
HORIZONTAL

PLOT
720
553
920
703
Money Supply
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SLIDER
885
126
1017
159
Pop-Increase
Pop-Increase
0
20
0.0
.01
1
%
HORIZONTAL

SWITCH
884
11
1019
44
Pay-Dividend
Pay-Dividend
0
1
-1000

MONITOR
1341
442
1425
487
Long Term GDP
gdp-overall-growth / ( ticks / year-division )
2
1
11

PLOT
924
394
1125
544
Per Capita Productivity
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""
"reference" 1.0 0 -955883 true "" ""

PLOT
923
705
1125
855
$ Per Capita Productivity
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SLIDER
1030
88
1168
121
Income-tax
Income-tax
0
.999
0.0
.001
1
NIL
HORIZONTAL

SLIDER
1030
132
1166
165
Jobless-Benefits
Jobless-Benefits
0
5
0.0
.1
1
NIL
HORIZONTAL

SLIDER
1030
170
1168
203
Dividend-Tax
Dividend-Tax
0
.99
0.0
.01
1
NIL
HORIZONTAL

MONITOR
1341
492
1425
537
Long Term M0
overall-money-supply-increase / ( ticks / year-division )
2
1
11

SLIDER
136
244
256
277
Year-Division
Year-Division
1
12
4.0
1
1
NIL
HORIZONTAL

MONITOR
800
148
867
193
Year
Ticks / year-division
0
1
11

SLIDER
1174
10
1302
43
close-sensitivity
close-sensitivity
1
100
5.0
1
1
NIL
HORIZONTAL

PLOT
1125
244
1325
394
Wage/Price
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

BUTTON
1342
548
1434
581
Deflate Money
deflate-money
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
1343
588
1463
621
Money-Deflation
Money-Deflation
10
100
100.0
10
1
NIL
HORIZONTAL

SLIDER
1175
45
1304
78
Reserve
Reserve
0
100
0.0
1
1
NIL
HORIZONTAL

MONITOR
1341
393
1425
438
Banks
count patches with [ bank-id > 0 ]
0
1
11

MONITOR
1341
343
1449
388
Loans
sum [ loans ] of patches * -1
2
1
11

SLIDER
1175
118
1305
151
Principle
Principle
0
.1
0.0
.001
1
NIL
HORIZONTAL

MONITOR
1342
294
1448
339
Equity
Sum [ equity ] of patches
2
1
11

SWITCH
137
282
243
315
Child-Care
Child-Care
0
1
-1000

PLOT
720
705
921
855
% Businesses in Profit
NIL
NIL
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""
"reference" 1.0 0 -6459832 true "" ""

BUTTON
74
10
162
43
Run-H/G
\nHunter/Gatherer
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
12
10
67
43
NIL
Set-H/G
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1126
705
1328
855
Need Birth Buffer
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"Ave" 1.0 0 -16777216 true "" ""
"Max" 1.0 0 -2674135 true "" ""
"Min" 1.0 0 -13840069 true "" ""

SLIDER
571
11
743
44
renewable-soft-patch
renewable-soft-patch
0
2000
1260.0
10
1
NIL
HORIZONTAL

SLIDER
1175
155
1311
188
Job-Sight
Job-Sight
0
30
3.0
1
1
NIL
HORIZONTAL

PLOT
924
244
1125
394
Unemployment
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

PLOT
1331
704
1531
854
Child Caring
NIL
NIL
0.0
200.0
0.0
0.0
true
false
"" ""
PENS
"ave" 1.0 0 -16777216 true "" ""
"max" 1.0 0 -2674135 true "" ""
"min" 1.0 0 -13840069 true "" ""

SWITCH
885
163
1015
196
Hire-Efficiency
Hire-Efficiency
0
1
-1000

SWITCH
135
204
249
237
Child-Budget
Child-Budget
0
1
-1000

PLOT
1125
394
1325
544
Profit Rate
NIL
NIL
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

CHOOSER
573
493
711
538
Wealth-Defined
Wealth-Defined
"Money Only" "Assets"
0

INPUTBOX
1322
12
1448
72
Agent_Seed
-4.82354349E8
1
0
Number

INPUTBOX
1322
77
1450
137
Patch_Seed
-4.7597327E8
1
0
Number

BUTTON
1324
146
1449
179
New Agent Seed
set Agent_seed new-seed\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1325
186
1448
219
New Patch Seed
set Patch_seed new-seed
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
1458
101
1565
134
Input-Seeds
Input-Seeds
1
1
-1000

SWITCH
134
89
248
122
Share-Stores
Share-Stores
1
1
-1000

SWITCH
135
355
246
388
NBB_Evolve
NBB_Evolve
0
1
-1000

SWITCH
1345
664
1471
697
eternal-children
eternal-children
1
1
-1000

@#$#@#$#@
## WHAT IS IT?

This is a 'living' population that can run in two economic systems -- hunter/gatherer and monetary trade societies.

'Living agents' require food to survive and reproduce. The agents have the ability to evolve their behaviour. If the wrong behaviour evolves, it is possible for the population will go extinct. On the other hand, agents can be set to be eternal, so they live no matter what happens. 

There is a switch called **Mortality** that controls whether the agents are mortal or eternal. One use is to test how long-term economic predictions might differ when using 'eternal' agents rather than 'living agents'.

NOTE: if you use the hunter/gather mode, it is strongly recommended to you turn down the ***max-renewable-resources*** to 15 or you will end up with a huge population and a personal computer will struggle.

There are also two sets of Setup and Go buttons ... one labelled **H/G** (hunter gatherer) and the other labelled **Monetary**. The **H/G** buttons setup and runs the Hunter/Gatherer society while the **Monetary** buttons setup and runs the monetary economy. They have to be used together. You cannot mix them.

Finally, the user can lock the environment by setting the **Input Seeds** to ON. This allows the user start the simulation with identical agents in identical places in an identical environment (this is all random when **Input-Seeds** is set to OFF) and directly compare the performance of the two societies.

This model accompanies the book **Economics for a Fairer Society: Going Back to Basics using Agent-based Models**.


### Modification of Metaphoria - eternal population with mutation.

This model features an eternal population (**Mortality** = off) with mutation. In order to use the same code as that of the mortal population, this population features death. When an agent dies, it is resurrected having put its variables through the same mutation code as that of the mortal population. The population level stays the same.

The **eternal-children** switch determines whether the resurrected agents begin as children or not.

The **%-Food-Inherit** slider determines how much food is inherited from the dead agent.


## HOW IT WORKS

Each patch in the environment has a random amount of food on it covered by a random amount of resistance. All the agents have the same amount of labour with which to overcome the resistant and harvest the food. If two or more agents occupy the same patch, their labour is added. The agents in this simulation must find enough food to stay alive and breed. The monetary population works entirely on price signals whereas the hunter/gatherer economic organisation relies on emergent behaviour.

## HOW TO USE IT

Press the buttons **[Set-H/G]** and then **[Run-H/G]** to run the hunter/gatherer population.

Press the buttons **[Set-Monetary]** and then **[Run-Monetary]** to run the monetary population.

## Controls

### Buttons

**Deflate Money** - Deflates the stocks of money. Works by dividing the stocks by the number set in the _Money-Deflation_ slider.

**New Agent Seed** - Sets a new seed for the creation of a population. The same seed will create the same population if the relevant sliders remain the same.

**New Patch Seed** - Sets a new seed for the creation of the environment. The same seed will create the same population if the relevant sliders remain the same.

**Run-H/G** - Runs the hunter/gatherer economic organisation.

**Run-Monetary** - Runs the monetary economic organisation.

**Set-H/G** - Sets up the environment and the agents for a hunter/gatherer economic organisation.

**Set-Monetary** - Sets up the environment and the agents for a monetary economic organisation.


### Sliders


**Asset-Tax** - This determines the level the tills of the shops are taxed at the percent given once per (iteration x _Year-Division_).

**bottom-wealth-cutoff-%** - not used yet.

**Buy-cycles** - Determines how many times an agent can make a purchase between its pay periods.

**charting-interval** - Sets the number of iterations in each graph plot.

**Child-Dependency** - Determines the length of time an agent is dependent on their parent.

**Child-Bearing** - Determines the minimum age that an agent can reproduce.

**close-sensitivity**  - If there is no business activity after close-sensitivity x _Year-Division_ iterations.

**Dividend-Tax** - Determines taxes on the dividends given to business and bank owners.

**Fertility** - An evolved fertility variable each agent possesses that determines how likely reproduction will take place.

**Income-tax** - Determines taxes on the income of the agents at a rate of once per (iteration x _Year-Division_).

**Inheritance** - Determines the nature of inheritance in the following manner:

0 - the inheritance will go the nearest agent.
1 - if a child dies, its assets go to its parents. If there are none, then '0'.
2 - The assets go to the children. If there are none, then '0'.
3 - If there are no children, the assets go to the parents. If there are none, then '0'.
4 - If there are no children or parents, the assets go to a sibling. If there are none, then '0'.

**Interest** - This determines the interest charged on a loan every (iteration x _Year-Division_)

**Job-Sight** - Determines how far an agent looks for employment.

**Jobless-Benefits** - Gives unemployed agents an income equal to the system's average wage x _Jobless-Benefits_.

**Market-Sight** - Determines how far an agent looks when purchasing goods.

**max-renewable-resources** - Sets the maximum amount of food available at any given patch.

**middle-wealth-cutoff-%** - not used yet.

**Min-Food** - Determines the quantity of food each agent consumes each year in order to stay alive.

**Money-Deflation** - Works with the _Deflate-Money_ button. Sets the amount of deflation.

**Need-Birth-Buffer** - An evolved variable that determines how much food an agent requires before reproducing.

**Old-Age** - The age after which the agent is considered 'old' if it dies. After this age, the agent has a 1 in 7 chance of dying every iteration.

**Pop-Increase** - Allows the user to increase a non-reproductive population.

**Population** - Sets the initial number of agents in the environment.

**Principle** - This determines the amount of the loan repayment as a percentage of the loan. Note that the _Principle_ should always be higher than _Interest_.

**Property-Tax** - This taxes the agents' stock of money (because at the moment it is the only real asset they have) at a rate of once per (iteration x _Year-Division_).

**Renewable-Harshness** - Sets the maximum resistance to harvesting possible at any given patch.

**renewable-soft-patch** - Sets the number of patches with harvest resistance reduced to 1.

**Reserve** - This is the amount of fiat money that can be given out before banks begin giving out loans.

**Start-charts** - The iteration where the graphs start charting.

**Starting-Labour** - Determines how much labour each agent can exert each year.

**Stop-Simulation** - Stops the simulation at the set iteration.

**Trade-Minimum** - Determines the minimum possible trade. Not only is this realistic, it prevents trade amounts approaching zero and causing crashes.

**Year-Division** - Sets how many times the production and pay cycles occur in any given year.

**%-Food-Inherit** - Determines the percentage of a dead agent's food stock in included in its inheritance.



### Switches

**Child-Budget** - Turns on the parent agent's awareness of the need to get food for a child.

**Child-Care** - Controls whether children need food or not.

**eternal-children** - When 'true' a resurrected agent from an eternal population (**Mortality** is off), the new agent will be a child and thus unable to work until it gets older.

**Hire-Efficiency** - Determines whether businesses only hire to their greatest profit or they take on extra workers.

**Input-Seeds** - When switched on, the random number generators take the seed shown in the relevant input windows.

**Mortality** - When turned on, agents have a set life-span, reproduce, and require food in order to stay alive.

**NBB_Evolve** - Determines whether the agents evolve their need for food before reproduction or whether it is user set.

**Pay-Dividend** - Determines whether business pass on their profits to their owner or not.

**Sexual-Rep** - Determines whether new agents are the result of combining the characteristics of two agents + mutation (sexual) or a clone + mutation of one agent (non-sexual)

**Share-Stores** - In Hunter/Gatherer mode, has the agents put all their food in the shared pot before distributing the harvest.

**Unlimited-Demand** - Turns on unrestrained demand. When turned off, the agents only buy what they need and then they stop.


## Plots and Monitors

### Plots

Note on charts: Many of them are averaged by the number of iterations set on the _Charting-Interval_ slider. Charting every iteration makes illegible charts. Averaging them makes it much easier to see the trends.

**Birth and Death** - Charts the birth rate and the death rate on the same chart. The middle horizontal line is 0 for both charts. The birth rate is positively charted above the 0 line by summing all births and dividing by the population in the previous iteration. The death rate is negatively charted below the 0 line and sums all deaths and divides by the population in the previous iteration. The horizontal orange lines are for reference only and are set at .5 and -.5.

**Cause of Death** - The green line sums all the agents who died because of starvation and divides by the population. The black line sums all the deaths due to old age and divides by the population. The pink line sums all the deaths of children and divides by the population.

**Child-Caring** - This tracks an agent evolutionary variable for Hunter/Gatherers only. The variable controls the food buffer a Hunter/Gatherer parent tries to set for its child while it is being raised.

**GDP** - The sum of the value of all purchases.

**Gini Coefficient** - The Gini coefficient of wealth according to _Wealth-Defined_.

**Longevity** - Sums the age reached by all agents who died during that iteration and divides by the number of deaths.

**Money Supply** - The amount of money in the system.

**Need-Birth-Buffer** - Charts the need-birth-buffer evolutionary variable. Red line is the value of the agent with the maximum value, the green line is the lowest value in the system, and the black line is the system average. This is how I chart all evolutionary variables.

**Needs per Capita** - Sum of needs (food) possessed by agents / population

**Needs Price** - The average price in the system.

**Needs Wage** - The average wage in the system.

**Per Capita Productivity** - The total need harvest/adult population.

**Percent in Profit** - The number of businesses with more money in their till than last turn / all businesses.

**Population** - Then number of agents.

**Profit Rate** - How much more money there is in the till of all businesses, on average.

**Real Production** - Sum of all harvested.

**Unemployment** - From the population of adult agents, the unemployed / agents.

**Wage/Price Ratio** - Divides the system's average wage by the average price.

**$ Per Capita Productivity** - The GDP / adult population.


### Monitors

**Banks** - Number of banks.

**Count Turtles** - Gives a continuous numerical count of turtles.

**Businesses** - Counts the number of businesses.

**Equity** - The total amount of money in the business's tills.

**Loans** - Total outstanding loans.

**Long Term GDP** = 100 x Sum (((GDP (current) - GDP (previous)) / GDP (previous)) / time

**Long Term M0** = 100 x Sum (((M0 (current) - M0 (previous)) / M0 (previous)) / time

**Money** - This is a development monitor designed to ensure there are no money leaks in the system. Should be a 0 except while the simulation is moving money about.

**Year** - Depending on user settings, this simulation can run several sections of a year in any given iteration. This monitor keeps track of what year it is. Time is based on a reproductive baseline.


## CREDITS AND REFERENCES

Copyright Tim Gooding 2019.

This model is licensed by the Creative Commons Attribution-NonCommercial-ShareAlike License ( http://creativecommons.org/licenses/by-nc-sa/4.0/ ). This states that you may copy, distribute, and transmit the work under the condition that you give attribution to Gooding 2019, your use is for non-commercial purposes, and you release any work derived from this work under the same license agreement.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="20" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="Interest">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Job-Sight">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Principle">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Hire-Efficiency">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Pay-Dividend">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Fertility">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Share-Stores">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="renewable-soft-patch">
      <value value="1210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Life">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Unlimited-Demand">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Stop-Simulation">
      <value value="12000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Renewable-Harshness">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_Seed">
      <value value="-364258103"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Year-Division">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Start-Charts">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Input-Seeds">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Property-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Trade-Minimum">
      <value value="0.00108"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Population">
      <value value="950"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Sexual-Rep">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Reserve">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Pop-Increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wealth-Defined">
      <value value="&quot;Money Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Patch_Seed">
      <value value="1447744687"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chart-interval">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Budget">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Dependency">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Inheritance">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Dividend-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Food-Inherit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Market-Sight">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-food">
      <value value="2.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="close-sensitivity">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Buy-cycles">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Jobless-Benefits">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="NBB_Evolve">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Care">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Money-Deflation">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Starting-Labour">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middle-wealth-cutoff-%">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Bearing-Age">
      <value value="14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="old-age">
      <value value="85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="need-birth-buffer">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Asset-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Income-tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-wealth-cutoff-%">
      <value value="0.43"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-renewable-resources">
      <value value="52"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="20" runMetricsEveryStep="true">
    <setup>set-monetary</setup>
    <go>monetary</go>
    <metric>gi</metric>
    <enumeratedValueSet variable="Interest">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Job-Sight">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Principle">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Hire-Efficiency">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Pay-Dividend">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Fertility">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Share-Stores">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="renewable-soft-patch">
      <value value="1210"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Life">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Unlimited-Demand">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Stop-Simulation">
      <value value="12000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Renewable-Harshness">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_Seed">
      <value value="-364258103"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Year-Division">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Start-Charts">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Input-Seeds">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Property-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Trade-Minimum">
      <value value="0.00108"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Population">
      <value value="950"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Sexual-Rep">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Reserve">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Pop-Increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wealth-Defined">
      <value value="&quot;Money Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Patch_Seed">
      <value value="1447744687"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chart-interval">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Budget">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Dependency">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Inheritance">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Dividend-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Food-Inherit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Market-Sight">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-food">
      <value value="2.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="close-sensitivity">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Buy-cycles">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Jobless-Benefits">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="NBB_Evolve">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Care">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Money-Deflation">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Starting-Labour">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middle-wealth-cutoff-%">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Bearing-Age">
      <value value="14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="old-age">
      <value value="85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="need-birth-buffer">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Asset-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Income-tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-wealth-cutoff-%">
      <value value="0.43"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-renewable-resources">
      <value value="52"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no interest mortal 50" repetitions="50" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>gi</metric>
    <metric>ex-prod</metric>
    <metric>ex-wp</metric>
    <metric>p-r</metric>
    <metric>ui</metric>
    <metric>gdp-plot</metric>
    <enumeratedValueSet variable="Job-Sight">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Interest">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Principle">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Hire-Efficiency">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Pay-Dividend">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Fertility">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Share-Stores">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="renewable-soft-patch">
      <value value="1260"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Unlimited-Demand">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mortality">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Renewable-Harshness">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Stop-Simulation">
      <value value="2300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_Seed">
      <value value="1473827466"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Year-Division">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Start-Charts">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Property-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Input-Seeds">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Trade-Minimum">
      <value value="0.00108"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Population">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Reserve">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Sexual-Rep">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Pop-Increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wealth-Defined">
      <value value="&quot;Money Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Patch_Seed">
      <value value="-526004649"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chart-interval">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Budget">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Dependency">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Inheritance">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Dividend-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Food-Inherit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Market-Sight">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-food">
      <value value="2.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="close-sensitivity">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Buy-cycles">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Jobless-Benefits">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="NBB_Evolve">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Care">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Money-Deflation">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Starting-Labour">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middle-wealth-cutoff-%">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Bearing-Age">
      <value value="14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="old-age">
      <value value="85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="need-birth-buffer">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Income-tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-wealth-cutoff-%">
      <value value="0.43"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Asset-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-renewable-resources">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="no interest mortal 50" repetitions="50" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>gi</metric>
    <metric>ex-prod</metric>
    <metric>ex-wp</metric>
    <metric>p-r</metric>
    <metric>ui</metric>
    <metric>gdp-plot</metric>
    <enumeratedValueSet variable="Interest">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Job-Sight">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Principle">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Hire-Efficiency">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Pay-Dividend">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Fertility">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Share-Stores">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="renewable-soft-patch">
      <value value="1260"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Unlimited-Demand">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mortality">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Renewable-Harshness">
      <value value="35"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Stop-Simulation">
      <value value="2600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Agent_Seed">
      <value value="1030236906"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Year-Division">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Start-Charts">
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Input-Seeds">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Property-Tax">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Trade-Minimum">
      <value value="0.00108"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Population">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Reserve">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Sexual-Rep">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Pop-Increase">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Wealth-Defined">
      <value value="&quot;Money Only&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Patch_Seed">
      <value value="-62163130"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="chart-interval">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Budget">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Dependency">
      <value value="16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Inheritance">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Dividend-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-Food-Inherit">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Market-Sight">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-food">
      <value value="1.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="close-sensitivity">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Buy-cycles">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Jobless-Benefits">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="NBB_Evolve">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Care">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Money-Deflation">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Starting-Labour">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="middle-wealth-cutoff-%">
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Child-Bearing-Age">
      <value value="14"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="old-age">
      <value value="85"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="need-birth-buffer">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottom-wealth-cutoff-%">
      <value value="0.43"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Income-tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Asset-Tax">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-renewable-resources">
      <value value="50"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
